@@ -24,6 +24,7 @@ def cli(domain: str,
          reports_path, 
          reports_list=[],
          summary_filepath="", 
+         log_path="",
          report="", 
          path="", 
          threads=0, 
@@ -43,6 +44,7 @@ def cli(domain: str,
     run(domain=domain,
         reports_path=reports_path,
         summary_filepath=summary_filepath,
+        log_path=log_path,
         report=report, 
         path=path, 
         threads=threads, 
